@@ -2,14 +2,14 @@ package Test2::Plugin::Cover;
 use strict;
 use warnings;
 
-use Test2::API qw/test2_add_callback_exit test2_add_callback_context_init context/;
+use Test2::API qw/test2_add_callback_exit context/;
 use Path::Tiny qw/path/;
 use Carp qw/croak/;
 use File::Spec();
 
 my $SEP = File::Spec->catfile('', '');
 
-our $VERSION = '0.000020'; # TRIAL
+our $VERSION = '0.000021'; # TRIAL
 
 # Directly modifying this is a bad idea, but for the XS to work it needs to be
 # a package var, not a lexical.
@@ -20,6 +20,7 @@ my $FROM_MANAGER;
 our $ROOT;
 BEGIN { $ROOT = "" . path('.')->realpath }
 
+our %SEEN;
 my %REPORT;
 our @TOUCHED;
 our @OPENED;
@@ -47,7 +48,6 @@ sub import {
     my $callback = sub { return if $ran++; $class->report(%params, ctx => $_[0], root => $ROOT) };
 
     test2_add_callback_exit($callback);
-    test2_add_callback_context_init(sub { $class->_process(%params) });
 
     # Fallback if we fork.
     eval 'END { local $?; $callback->() }; 1' or die $@;
@@ -68,6 +68,7 @@ sub reset_coverage {
     @TOUCHED = ();
     @OPENED  = ();
     %REPORT  = ();
+    %SEEN    = ();
 }
 
 sub set_root { $ROOT = "" . pop };
